@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2015-12-23'; # DATE
-our $VERSION = '0.73'; # VERSION
+our $DATE = '2015-12-28'; # DATE
+our $VERSION = '0.74'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -29,6 +29,7 @@ sub _md2pod {
 # the name, we'll just do everything in after_gen_doc().
 sub after_gen_doc {
     require Data::Dump::SortKeys;
+    local $Data::Dump::SortKeys::REMOVE_PRAGMAS = 1;
 
     my ($self) = @_;
 
@@ -65,11 +66,22 @@ sub after_gen_doc {
     my $orig_args_as = $meta->{_orig_args_as} // 'hash';
     my $i = 0;
     my @eg_lines;
+    my $arg_sorter = do {
+        require Perinci::Sub::Util::Sort;
+        require Sort::ByExample;
+        my $sorter = Sort::ByExample::sbe(
+            [ Perinci::Sub::Util::Sort::sort_args($meta->{args}) ]);
+        sub {
+            my $hash = shift;
+            $sorter->(keys %$hash);
+        };
+    };
   EXAMPLE:
     for my $eg (@$examples) {
         $i++;
         my $argsdump;
         if ($eg->{args}) {
+            local $Data::Dump::SortKeys::SORT_KEYS = $arg_sorter;
             if ($orig_args_as =~ /array/) {
                 require Perinci::Sub::ConvertArgs::Array;
                 my $cares = Perinci::Sub::ConvertArgs::Array::convert_args_to_array(
@@ -89,6 +101,7 @@ sub after_gen_doc {
                 }
             }
         } elsif ($eg->{argv}) {
+            local $Data::Dump::SortKeys::SORT_KEYS = $arg_sorter;
             if ($orig_args_as =~ /hash/) {
                 require Perinci::Sub::GetArgs::Argv;
                 my $gares = Perinci::Sub::GetArgs::Argv::get_args_from_argv(
@@ -385,7 +398,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.73 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-23.
+This document describes version 0.74 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2015-12-28.
 
 =head1 SYNOPSIS
 
@@ -407,7 +420,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
